@@ -66,6 +66,7 @@ sub copy_dialog_msgs {
 	   "pt" => "Copiar",
 	   "pt_PT" => "Copiar",
 	   "ru" => "Копировать",
+	   "sl" => "Kopiraj",
 	   "sr" => "Копирај",
 	   "sr\@latin" => "Kopiraj",
 	   "tr" => "Kopyala",
@@ -88,6 +89,7 @@ sub copy_dialog_msgs {
 	   "pt" => "Nome do ficheiro:",
 	   "pt_PT" => "Nome do ficheiro:",
 	   "ru" => "Имя файла:",
+	   "sl" => "Ime datoteke",
 	   "sr" => "Име фајла:",
 	   "sr\@latin" => "Ime fajla:",
 	   "tr" => "Dosya adı:",
@@ -120,6 +122,7 @@ sub rename_dialog_msgs {
 	   "pt" => "Mudar o nome",
 	   "pt_PT" => "Mudar o nome",
 	   "ru" => "Переместить/переименовать",
+	   "sl" => "Premakni/preimenuj",
 	   "sr" => "Премести/преименуј",
 	   "sr\@latin" => "Premesti/preimenuj",
 	   "tr" => "Taşı/Yeniden İsimlendir",
@@ -145,6 +148,7 @@ sub rename_dialog_msgs {
 	   "pt" => "Novo nome:",
 	   "pt_PT" => "Novo nome:",
 	   "ru" => "Новое имя:",
+	   "sl" => "Novo ime",
 	   "sr" => "Ново име:",
 	   "sr\@latin" => "Novo ime:",
 	   "tr" => "Yeni isim:",
@@ -177,6 +181,7 @@ sub delete_dialog_msgs {
 	   "pt" => "Atenção",
 	   "pt_PT" => "Atenção",
 	   "ru" => "Внимание",
+	   "sl" => "Opozorilo",
 	   "sr" => "Упозорење",
 	   "sr\@latin" => "Upozorenje",
 	   "tr" => "Uyarı",
@@ -203,6 +208,7 @@ sub delete_dialog_msgs {
 	   "pt" => "Tem a certeza que quer apagar definitivamente? ",
 	   "pt_PT" => "Tem a certeza que quer apagar definitivamente? ",
 	   "ru" => "Вы уверены, что хотите удалить:",
+	   "sl" => "Ali ste prepričani, da želite izbrisati: ",
 	   "sr" => "Желите ли заиста да обришете: ",
 	   "sr\@latin" => "Želite li zaista da obrišete: ",
 	   "tr" => "Bu dosyayı kalıcı olarak silmek istediğinize emin misiniz: ",
@@ -235,6 +241,7 @@ sub ownership_dialog_msgs {
 	   "pt" => "Atribuir UID:GID",
 	   "pt_PT" => "Atribuir UID:GID",
 	   "ru" => "Установить UID:GID",
+	   "sl" => "Nastavi UID:GID",
 	   "sr" => "Постави УИД:ГИД",
 	   "sr\@latin" => "Postavi UID:GID",
 	   "tr" => "UID:GID'i ayarla",
@@ -261,6 +268,7 @@ sub ownership_dialog_msgs {
 	   "pt" => "Alterar dono para: ",
 	   "pt_PT" => "Alterar dono para: ",
 	   "ru" => "Сменить владельца на:",
+	   "sl" => "Spremeni lastnika: ",
 	   "sr" => "Промени власника: ",
 	   "sr\@latin" => "Promeni vlasnika: ",
 	   "tr" => "Dosyanın sahibini değiştir: ",
@@ -290,6 +298,7 @@ sub recursion_dialog_msgs {
 	   "pt" => "Aplicar alterações recursivamente?",
 	   "pt_PT" => "Aplicar alterações recursivamente?",
 	   "ru" => "Применить изменения рекурсивно?",
+	   "sl" => "Uveljavim spremembe rekurzivno?",
 	   "sr" => "Да применим измене рекурзивно?",
 	   "sr\@latin" => "Da primenim izmene rekurzivno?",
 	   "tr" => "Değişiklikler özyinelemeli olarak uygulansın mı?",
@@ -313,6 +322,7 @@ sub recursion_dialog_msgs {
 	   "pt" => "Deseja aplicar as alterações recursivamente a todos os sub-directórios e ficheiros? \n(Usar com cuidado)",
 	   "pt_PT" => "Deseja aplicar as alterações recursivamente a todos os sub-directórios e ficheiros? \n(Usar com cuidado)",
 	   "ru" => "Вы хотите применить изменения рекурсивно для всех подпапок и файлов",
+	   "sl" => "Ali želite uveljaviti spremembe rekurzivno na vse podmape in datoteke? \n (Uporabite pazljivo)",
 	   "sr" => "Желите ли да примените измене рекурзивно на све потфасцикле и фајлове? \n(Користите ово пажљиво)",
 	   "sr\@latin" => "Želite li da primenite izmene rekurzivno na sve potfascikle i fajlove? \n(Koristite ovo pažljivo)",
 	   "tr" => "Değişiklikleri tüm altdizinlere ve dosyalara özyinelemeli olarak uygulamak istiyor musunuz? \n(Dikkatli kullanın",
@@ -342,6 +352,7 @@ sub root_reminder_msgs {
 	   "pt" => "ABERTO COMO ROOT",
 	   "pt_PT" => "ABERTO COMO ROOT",
 	   "ru" => "Открыто как root",
+	   "sl" => "ODPRTO KOT ADMINISTRATOR",
 	   "sr" => "ОТВОРЕНО КАО КОРЕН",
 	   "sr\@latin" => "OTVORENO KAO KOREN",
 	   "tr" => "YETKİLİ KULLANICI OLARAK AÇILDI",
@@ -374,6 +385,7 @@ sub open_dialog_msgs {
 	   "pt" => "Programa",
 	   "pt_PT" => "Programa",
 	   "ru" => "Программа",
+	   "sl" => "Program",
 	   "sr" => "Програм",
 	   "sr\@latin" => "Program",
 	   "tr" => "Program",
@@ -400,6 +412,7 @@ sub open_dialog_msgs {
 	   "pt" => "Abrir com: ",
 	   "pt_PT" => "Abrir com: ",
 	   "ru" => "Открыть с помощью: ",
+	   "sl" => "Odpri z: ",
 	   "sr" => "Отвори помоћу: ",
 	   "sr\@latin" => "Otvori pomoću: ",
 	   "tr" => "Birlikte aç: ",
@@ -432,6 +445,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Permissões",
 	   "pt_PT" => "Permissões",
 	   "ru" => "Резрешения",
+	   "sl" => "Dovoljenja",
 	   "sr" => "Дозволе",
 	   "sr\@latin" => "Dozvole",
 	   "tr" => "Yetkiler",
@@ -458,6 +472,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Escolher permissões: ",
 	   "pt_PT" => "Escolher permissões: ",
 	   "ru" => "Выбрать разрешения: ",
+	   "sl" => "Izberite dovoljenja: ",
 	   "sr" => "Изаберите дозволе: ",
 	   "sr\@latin" => "Izaberite dozvole: ",
 	   "tr" => "Yetkileri belirle: ",
@@ -484,6 +499,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Dono:",
 	   "pt_PT" => "Dono:",
 	   "ru" => "Владелец:",
+	   "sl" => "Lastnik: ",
 	   "sr" => "Власник:",
 	   "sr\@latin" => "Vlasnik:",
 	   "tr" => "Sahip:",
@@ -510,6 +526,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Grupo:",
 	   "pt_PT" => "Grupo:",
 	   "ru" => "Группа:",
+	   "sl" => "Skupina:",
 	   "sr" => "Група:",
 	   "sr\@latin" => "Grupa:",
 	   "tr" => "Grup",
@@ -536,6 +553,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Todos:",
 	   "pt_PT" => "Todos:",
 	   "ru" => "Другие:",
+	   "sl" => "Ostali:",
 	   "sr" => "Остали:",
 	   "sr\@latin" => "Ostali:",
 	   "tr" => "Diğerleri:",
@@ -562,6 +580,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Especial:",
 	   "pt_PT" => "Especial:",
 	   "ru" => "Специальный:",
+	   "sl" => "Posebno:",
 	   "sr" => "Посебно:",
 	   "sr\@latin" => "Posebno:",
 	   "tr" => "Özel:",
@@ -588,6 +607,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Permissão de leitura",
 	   "pt_PT" => "Permissão de leitura",
 	   "ru" => "Разрешён для чтения",
+	   "sl" => "branje",
 	   "sr" => "читање",
 	   "sr\@latin" => "čitanje",
 	   "tr" => "okunabilir",
@@ -614,6 +634,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Permissão de escrita",
 	   "pt_PT" => "Permissão de escrita",
 	   "ru" => "Разрешён для записи",
+	   "sl" => "pisanje",
 	   "sr" => "упис",
 	   "sr\@latin" => "upis",
 	   "tr" => "yazılabilir",
@@ -640,6 +661,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Executável",
 	   "pt_PT" => "Executável",
 	   "ru" => "Исполняемый",
+	   "sl" => "izvajanje",
 	   "sr" => "извршна",
 	   "sr\@latin" => "izvršna",
 	   "tr" => "çalıştırılabilir",
@@ -666,6 +688,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Definir o bit ID de utilizador",
 	   "pt_PT" => "Definir o bit ID de utilizador",
 	   "ru" => "Установить UID пользователя",
+	   "sl" => "nastvi UID",
 	   "sr" => "стави УИД",
 	   "sr\@latin" => "stavi UID",
 	   "tr" => "kullanıcı ID bitini ayarla",
@@ -692,6 +715,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Definir o bit ID de grupo",
 	   "pt_PT" => "Definir o bit ID de grupo",
 	   "ru" => "Установить GID группы",
+	   "sl" => "nastavi GID",
 	   "sr" => "стави ГИД",
 	   "sr\@latin" => "stavi GID",
 	   "tr" => "grup ID bitini ayarla",
@@ -718,6 +742,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Definir o bit 'sticky'",
 	   "pt_PT" => "Definir o bit 'sticky'",
 	   "ru" => "Установить липкий бит",
+	   "sl" => "nastavi lepljivo",
 	   "sr" => "стави лепљиву",
 	   "sr\@latin" => "stavi lepljivu",
 	   "tr" => "yapışkan biti ayarla",
@@ -744,6 +769,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Atenção",
 	   "pt_PT" => "Atenção",
 	   "ru" => "Внимание",
+	   "sl" => "Opozorilo",
 	   "sr" => "Упозорење",
 	   "sr\@latin" => "Upozorenje",
 	   "tr" => "Dikkat",
@@ -770,6 +796,7 @@ sub permission_dialog_msgs {
 	   "pt" => "Escolheu definir as permissões especiais, tem a certeza que quer continuar?",
 	   "pt_PT" => "Escolheu definir as permissões especiais, tem a certeza que quer continuar?",
 	   "ru" => "Вы решили установить особые разрешения, вы уверены, что хотите продолжить?",
+	   "sl" => "Nastavili ste posebna dovoljenja, želite nadaljevati?",
 	   "sr" => "Поставили сте посебне дозволе, желите ли заиста да наставите?",
 	   "sr\@latin" => "Postavili ste posebne dozvole, želite li zaista da nastavite?",
 	   "tr" => "Özel yetki ayarları yapmayı seçtiniz, devam etmek istediğinize emin misiniz?",
@@ -840,7 +867,7 @@ if ( $#ARGV lt 0 ) {
 if ( `which kdesudo` ) {
 	$SUCOMMAND = "$KDEBINPATH"."kdesudo -d --noignorebutton --"}
 elsif ( `which kdesu` ) {
-	$SUCOMMAND = "$KDEBINPATH"."kdesu -d --"}
+	$SUCOMMAND = "$KDEBINPATH"."kdesu -d -c"}
 else { $SUCOMMAND = "xdg-su -c"}
 
 $DIALOGCOMMAND = "$KDEBINPATH"."kdialog" ;
@@ -898,16 +925,19 @@ sub open_with {
 	$TARGET = join("' '", @ARGV) ;
 
 	if ( $APPNAME eq "defaultfm" ) {
-	     chomp($APPNAME = `xdg-mime query default inode/directory | sed s/.desktop//`);
+	     chomp($APPNAME = `xdg-mime query default inode/directory | sed s/.desktop// | sed s/kde4-//`);
 	     if ( $APPNAME eq "kfmclient_dir" ) { $APPNAME = "konqueror"; }
-	     #use dolphin as fallback
+	     #Check that file manager is available
 	     system "which $APPNAME" ;
-	        if ( $? ne 0 ) { $APPNAME = "dolphin"; }
+	     if (( $? ne 0 ) || ( $APPNAME eq "" )) { 
+		if ( `which dolphin` ) { $APPNAME = "dolphin"; } #dolphin as fallback if available
+		else { $APPNAME = "konqueror"; } 
+	     }
 	}
 	elsif ( $APPNAME eq "defaultte" ) {
-	     chomp($APPNAME = `xdg-mime query default text/plain | sed s/.desktop//`);
+	     chomp($APPNAME = `xdg-mime query default text/plain | sed s/.desktop// | sed s/kde4-//`);
 	     system "which $APPNAME" ;
-	     if ( $? ne 0 ) { 
+	     if (( $? ne 0 ) || ( $APPNAME eq "" )) { 
 		if ( `which kate` ) { $APPNAME = "kate"; } #kate as fallback if available
 		else { $APPNAME = "kwrite"; } 
              }   
@@ -1017,6 +1047,21 @@ sub do_rename {
 }
 #---End rename subroutines---
 
+#---Compress subroutines---
+sub root_compress {
+	exec "$SUCOMMAND \"\'$EXECNAME\' do_compress \'$TARGET\'\"";
+}
+
+sub do_compress {
+	#If running as root, compress
+	if ( $> eq 0 ) {
+	   `ark --add --changetofirstpath --dialog \'$TARGET\'` ;
+	   exit 0;
+	}
+
+}
+#---End compress subroutines---
+
 #---Deletion subroutines---
 sub root_delete {
 	#Create a viewer friendly list of files to be deleted for the warning dialog
